You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by vk...@apache.org on 2014/12/11 14:54:41 UTC

[32/56] [abbrv] [partial] incubator-ignite git commit: Rename GridException to IgniteCheckedException, GridRuntimeException to IgniteException.

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheDataStructuresProxy.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheDataStructuresProxy.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheDataStructuresProxy.java
index 8e72f65..10eb802 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheDataStructuresProxy.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheDataStructuresProxy.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.datastructures;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.cache.datastructures.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.jetbrains.annotations.*;
@@ -52,7 +52,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Override public GridCacheAtomicSequence atomicSequence(String name, long initVal, boolean create)
-        throws GridException {
+        throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -64,7 +64,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeAtomicSequence(String name) throws GridException {
+    @Override public boolean removeAtomicSequence(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -76,7 +76,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public GridCacheAtomicLong atomicLong(String name, long initVal, boolean create) throws GridException {
+    @Override public GridCacheAtomicLong atomicLong(String name, long initVal, boolean create) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -88,7 +88,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeAtomicLong(String name) throws GridException {
+    @Override public boolean removeAtomicLong(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -101,7 +101,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Override public <T> GridCacheAtomicReference<T> atomicReference(String name, T initVal, boolean create)
-        throws GridException {
+        throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -113,7 +113,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeAtomicReference(String name) throws GridException {
+    @Override public boolean removeAtomicReference(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -126,7 +126,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Override public <T, S> GridCacheAtomicStamped<T, S> atomicStamped(String name, T initVal, S initStamp,
-        boolean create) throws GridException {
+        boolean create) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -138,7 +138,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeAtomicStamped(String name) throws GridException {
+    @Override public boolean removeAtomicStamped(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -151,7 +151,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Override public <T> GridCacheQueue<T> queue(String name, int cap, boolean collocated, boolean create)
-        throws GridException {
+        throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -163,7 +163,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeQueue(String name) throws GridException {
+    @Override public boolean removeQueue(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -175,7 +175,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeQueue(String name, int batchSize) throws GridException {
+    @Override public boolean removeQueue(String name, int batchSize) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -188,7 +188,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Nullable @Override public <T> GridCacheSet<T> set(String name, boolean collocated, boolean create)
-        throws GridException {
+        throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -200,7 +200,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeSet(String name) throws GridException {
+    @Override public boolean removeSet(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -213,7 +213,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
 
     /** {@inheritDoc} */
     @Nullable @Override public GridCacheCountDownLatch countDownLatch(String name, int cnt, boolean autoDel,
-        boolean create) throws GridException {
+        boolean create) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {
@@ -225,7 +225,7 @@ public class GridCacheDataStructuresProxy<K, V> implements GridCacheDataStructur
     }
 
     /** {@inheritDoc} */
-    @Override public boolean removeCountDownLatch(String name) throws GridException {
+    @Override public boolean removeCountDownLatch(String name) throws IgniteCheckedException {
         GridCacheProjectionImpl<K, V> old = gate.enter(null);
 
         try {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueProxy.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueProxy.java
index 6706e0e..d73cf72 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueProxy.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueProxy.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.cache.datastructures;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.datastructures.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.typedef.*;
@@ -84,8 +84,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.add(item);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -106,8 +106,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.offer(item);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -128,8 +128,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.addAll(items);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -151,8 +151,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.contains(item);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -173,8 +173,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.containsAll(items);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -198,8 +198,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
             else
                 delegate.clear();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -221,8 +221,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.remove(item);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -243,8 +243,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.removeAll(items);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -265,8 +265,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.isEmpty();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -287,8 +287,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.iterator();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -309,8 +309,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.toArray();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -332,8 +332,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.toArray(a);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -354,8 +354,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.retainAll(items);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -376,8 +376,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.size();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -398,8 +398,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.poll();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -420,8 +420,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.peek();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -445,8 +445,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
             else
                 delegate.clear(batchSize);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -467,8 +467,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.remainingCapacity();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -489,8 +489,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.drainTo(c);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -511,8 +511,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.drainTo(c, maxElements);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -533,8 +533,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.remove();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -555,8 +555,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.element();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -580,8 +580,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
             else
                 delegate.put(item);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -602,8 +602,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.offer(item, timeout, unit);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -624,8 +624,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.take();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -646,8 +646,8 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return delegate.poll(timeout, unit);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
         finally {
             gate.leave();
@@ -660,17 +660,17 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
     }
 
     /** {@inheritDoc} */
-    @Override public int capacity() throws GridException {
+    @Override public int capacity() throws IgniteCheckedException {
         return delegate.capacity();
     }
 
     /** {@inheritDoc} */
-    @Override public boolean bounded() throws GridException {
+    @Override public boolean bounded() throws IgniteCheckedException {
         return delegate.bounded();
     }
 
     /** {@inheritDoc} */
-    @Override public boolean collocated() throws GridException {
+    @Override public boolean collocated() throws IgniteCheckedException {
         return delegate.collocated();
     }
 
@@ -723,7 +723,7 @@ public class GridCacheQueueProxy<T> implements GridCacheQueue<T>, Externalizable
 
             return t.get1().dataStructures().queue(t.get2(), 0, false, false);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw U.withCause(new InvalidObjectException(e.getMessage()), e);
         }
         finally {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetProxy.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetProxy.java
index 81aa137..6f7078f 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetProxy.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetProxy.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.datastructures;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.cache.datastructures.*;
@@ -95,8 +96,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.size();
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -124,8 +125,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.isEmpty();
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -153,8 +154,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.contains(o);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -182,8 +183,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.toArray();
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -211,8 +212,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.toArray(a);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -240,8 +241,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.add(t);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -269,8 +270,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.remove(o);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -298,8 +299,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.containsAll(c);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -327,8 +328,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.addAll(c);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -356,8 +357,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.retainAll(c);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -385,8 +386,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.removeAll(c);
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -417,8 +418,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
                 else
                     delegate.clear();
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -446,8 +447,8 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
                 return delegate.iterator();
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
             finally {
                 gate.leave();
@@ -464,7 +465,7 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
     }
 
     /** {@inheritDoc} */
-    @Override public boolean collocated() throws GridException {
+    @Override public boolean collocated() throws IgniteCheckedException {
         return delegate.collocated();
     }
 
@@ -514,7 +515,7 @@ public class GridCacheSetProxy<T> implements GridCacheSet<T>, Externalizable {
 
             return t.get1().dataStructures().set(t.get2(), false, false);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             throw U.withCause(new InvalidObjectException(e.getMessage()), e);
         }
         finally {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridTransactionalCacheQueueImpl.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridTransactionalCacheQueueImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridTransactionalCacheQueueImpl.java
index 5abd2b7..6eb2a17 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridTransactionalCacheQueueImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridTransactionalCacheQueueImpl.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.cache.datastructures;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.cache.datastructures.*;
 import org.gridgain.grid.kernal.processors.cache.*;
@@ -37,7 +37,7 @@ public class GridTransactionalCacheQueueImpl<T> extends GridCacheQueueAdapter<T>
 
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
-    @Override public boolean offer(final T item) throws GridRuntimeException {
+    @Override public boolean offer(final T item) throws IgniteException {
         A.notNull(item, "item");
 
         try {
@@ -83,14 +83,14 @@ public class GridTransactionalCacheQueueImpl<T> extends GridCacheQueueAdapter<T>
 
             return retVal;
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
-    @Nullable @Override public T poll() throws GridRuntimeException {
+    @Nullable @Override public T poll() throws IgniteException {
         try {
             int cnt = 0;
 
@@ -130,8 +130,8 @@ public class GridTransactionalCacheQueueImpl<T> extends GridCacheQueueAdapter<T>
 
             return retVal;
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -187,14 +187,14 @@ public class GridTransactionalCacheQueueImpl<T> extends GridCacheQueueAdapter<T>
 
             return retVal;
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
-    @Override protected void removeItem(final long rmvIdx) throws GridException {
+    @Override protected void removeItem(final long rmvIdx) throws IgniteCheckedException {
         try {
             int cnt = 0;
 
@@ -228,8 +228,8 @@ public class GridTransactionalCacheQueueImpl<T> extends GridCacheQueueAdapter<T>
                 }
             }
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheOptimisticCheckPreparedTxFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheOptimisticCheckPreparedTxFuture.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheOptimisticCheckPreparedTxFuture.java
index 301aeaa..bedefa9 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheOptimisticCheckPreparedTxFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheOptimisticCheckPreparedTxFuture.java
@@ -152,7 +152,7 @@ public class GridCacheOptimisticCheckPreparedTxFuture<K, V> extends GridCompound
                     catch (ClusterTopologyException ignored) {
                         fut.onNodeLeft();
                     }
-                    catch (GridException e) {
+                    catch (IgniteCheckedException e) {
                         fut.onError(e);
 
                         break;
@@ -173,7 +173,7 @@ public class GridCacheOptimisticCheckPreparedTxFuture<K, V> extends GridCompound
                 catch (ClusterTopologyException ignored) {
                     fut.onNodeLeft();
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     fut.onError(e);
 
                     break;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxFuture.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxFuture.java
index e6a6fbf..1e31fdf 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxFuture.java
@@ -9,9 +9,9 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.*;
 import org.gridgain.grid.util.*;
@@ -142,7 +142,7 @@ public class GridCachePessimisticCheckCommittedTxFuture<K, V> extends GridCompou
                 catch (ClusterTopologyException ignored) {
                     fut.onNodeLeft();
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     fut.onError(e);
 
                     break;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxResponse.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxResponse.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxResponse.java
index 1577499..529edcb 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxResponse.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCachePessimisticCheckCommittedTxResponse.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
@@ -85,7 +85,7 @@ public class GridCachePessimisticCheckCommittedTxResponse<K, V> extends GridDist
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (committedTxInfo != null) {
@@ -96,7 +96,7 @@ public class GridCachePessimisticCheckCommittedTxResponse<K, V> extends GridDist
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (committedTxInfoBytes != null) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheTxFinishSync.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheTxFinishSync.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheTxFinishSync.java
index 8541d57..d71b4e9 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheTxFinishSync.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridCacheTxFinishSync.java
@@ -232,7 +232,7 @@ public class GridCacheTxFinishSync<K, V> {
                     return null;
 
                 if (nodeLeft)
-                    return new GridFinishedFutureEx<>(new GridException("Failed to wait for finish synchronizer " +
+                    return new GridFinishedFutureEx<>(new IgniteCheckedException("Failed to wait for finish synchronizer " +
                         "state (node left grid): " + nodeId));
 
                 if (pendingFut == null) {
@@ -274,7 +274,7 @@ public class GridCacheTxFinishSync<K, V> {
                 nodeLeft = true;
 
                 if (pendingFut != null) {
-                    pendingFut.onDone(new GridException("Failed to wait for transaction synchronizer " +
+                    pendingFut.onDone(new IgniteCheckedException("Failed to wait for transaction synchronizer " +
                         "completed state (node left grid): " + nodeId));
 
                     pendingFut = null;

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedBaseMessage.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedBaseMessage.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedBaseMessage.java
index eb67625..fd96d32 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedBaseMessage.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedBaseMessage.java
@@ -9,12 +9,12 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -100,7 +100,7 @@ public abstract class GridDistributedBaseMessage<K, V> extends GridCacheMessage<
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (candsByIdx != null)
@@ -117,7 +117,7 @@ public abstract class GridDistributedBaseMessage<K, V> extends GridCacheMessage<
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (candsByIdxBytes != null)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockRequest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxFinishRequest.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxFinishRequest.java
index e3a46a2..d2093c2 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxFinishRequest.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxFinishRequest.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
+import org.gridgain.grid.util.tostring.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
-import org.gridgain.grid.util.tostring.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -265,7 +265,7 @@ public class GridDistributedTxFinishRequest<K, V> extends GridDistributedBaseMes
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (writeEntries != null) {
@@ -295,7 +295,7 @@ public class GridDistributedTxFinishRequest<K, V> extends GridDistributedBaseMes
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (writeEntriesBytes != null) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareRequest.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareRequest.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareRequest.java
index 206f5d5..791c4f7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareRequest.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareRequest.java
@@ -9,13 +9,13 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
-import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -259,7 +259,7 @@ public class GridDistributedTxPrepareRequest<K, V> extends GridDistributedBaseMe
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (writes != null) {
@@ -291,7 +291,7 @@ public class GridDistributedTxPrepareRequest<K, V> extends GridDistributedBaseMe
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (writesBytes != null) {

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareResponse.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareResponse.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareResponse.java
index 6255b1b..2987382 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareResponse.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxPrepareResponse.java
@@ -9,12 +9,12 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -98,7 +98,7 @@ public class GridDistributedTxPrepareResponse<K, V> extends GridDistributedBaseM
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (candsBytes == null && cands != null) {
@@ -115,7 +115,7 @@ public class GridDistributedTxPrepareResponse<K, V> extends GridDistributedBaseM
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (candsBytes != null && cands == null)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridClientPartitionTopology.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridClientPartitionTopology.java
index 1ce0d4a..8053029 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridClientPartitionTopology.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridClientPartitionTopology.java
@@ -222,7 +222,7 @@ public class GridClientPartitionTopology<K, V> implements GridDhtPartitionTopolo
     }
 
     /** {@inheritDoc} */
-    @Override public boolean afterExchange(GridDhtPartitionExchangeId exchId) throws GridException {
+    @Override public boolean afterExchange(GridDhtPartitionExchangeId exchId) throws IgniteCheckedException {
         long topVer = exchId.topologyVersion();
 
         lock.writeLock().lock();

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAffinityAssignmentResponse.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAffinityAssignmentResponse.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAffinityAssignmentResponse.java
index 5ab7843..62923cb 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAffinityAssignmentResponse.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAffinityAssignmentResponse.java
@@ -9,8 +9,8 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed.dht;
 
+import org.apache.ignite.*;
 import org.apache.ignite.cluster.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
@@ -103,7 +103,7 @@ public class GridDhtAffinityAssignmentResponse<K, V> extends GridCacheMessage<K,
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (affAssignment != null)
@@ -111,7 +111,7 @@ public class GridDhtAffinityAssignmentResponse<K, V> extends GridCacheMessage<K,
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (affAssignmentBytes != null)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAssignmentFetchFuture.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAssignmentFetchFuture.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAssignmentFetchFuture.java
index 171b19e..81d176d 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAssignmentFetchFuture.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtAssignmentFetchFuture.java
@@ -159,7 +159,7 @@ public class GridDhtAssignmentFetchFuture<K, V> extends GridFutureAdapter<List<L
                     U.warn(log0, "Failed to request affinity assignment from remote node (node left grid, will " +
                         "continue to another node): " + node);
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     U.error(log0, "Failed to request affinity assignment from remote node (will " +
                         "continue to another node): " + node, e);
                 }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtCache.java
----------------------------------------------------------------------
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtCache.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtCache.java
index 7084396..b915079 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtCache.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridDhtCache.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed.dht;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.near.*;
 import org.gridgain.grid.util.tostring.*;
@@ -62,7 +62,7 @@ public class GridDhtCache<K, V> extends GridDhtTransactionalCacheAdapter<K, V> {
     }
 
     /** {@inheritDoc} */
-    @Override public void start() throws GridException {
+    @Override public void start() throws IgniteCheckedException {
         resetMetrics();
 
         super.start();
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueAdapter.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueAdapter.java
index 6eb742b..b3277ed 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueAdapter.java
@@ -118,7 +118,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
     }
 
     /** {@inheritDoc} */
-    @Override public int capacity() throws GridException {
+    @Override public int capacity() throws IgniteCheckedException {
         return cap;
     }
 
@@ -137,14 +137,14 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
             return hdr.size();
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
-    @Nullable @Override public T peek() throws GridRuntimeException {
+    @Nullable @Override public T peek() throws IgniteException {
         try {
             GridCacheQueueHeader hdr = (GridCacheQueueHeader)cache.get(queueKey);
 
@@ -155,8 +155,8 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
             return (T)cache.get(itemKey(hdr.head()));
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -190,13 +190,13 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
             return new QueueIterator(hdr);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
     /** {@inheritDoc} */
-    @Override public void put(T item) throws GridRuntimeException {
+    @Override public void put(T item) throws IgniteException {
         A.notNull(item, "item");
 
         if (!bounded()) {
@@ -214,7 +214,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
             catch (InterruptedException e) {
                 Thread.currentThread().interrupt();
 
-                throw new GridRuntimeException("Queue put interrupted.", e);
+                throw new IgniteException("Queue put interrupted.", e);
             }
 
             checkStopping();
@@ -225,7 +225,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
     }
 
     /** {@inheritDoc} */
-    @Override public boolean offer(T item, long timeout, TimeUnit unit) throws GridRuntimeException {
+    @Override public boolean offer(T item, long timeout, TimeUnit unit) throws IgniteException {
         A.notNull(item, "item");
         A.ensure(timeout >= 0, "Timeout cannot be negative: " + timeout);
 
@@ -252,7 +252,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
             catch (InterruptedException e) {
                 Thread.currentThread().interrupt();
 
-                throw new GridRuntimeException("Queue put interrupted.", e);
+                throw new IgniteException("Queue put interrupted.", e);
             }
 
             if (retVal)
@@ -263,7 +263,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public T take() throws GridRuntimeException {
+    @Nullable @Override public T take() throws IgniteException {
         while (true) {
             try {
                 readSem.acquire();
@@ -271,7 +271,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
             catch (InterruptedException e) {
                 Thread.currentThread().interrupt();
 
-                throw new GridRuntimeException("Queue take interrupted.", e);
+                throw new IgniteException("Queue take interrupted.", e);
             }
 
             checkStopping();
@@ -284,7 +284,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
     }
 
     /** {@inheritDoc} */
-    @Nullable @Override public T poll(long timeout, TimeUnit unit) throws GridRuntimeException {
+    @Nullable @Override public T poll(long timeout, TimeUnit unit) throws IgniteException {
         A.ensure(timeout >= 0, "Timeout cannot be negative: " + timeout);
 
         long end = U.currentTimeMillis() + MILLISECONDS.convert(timeout, unit);
@@ -302,7 +302,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
             catch (InterruptedException e) {
                 Thread.currentThread().interrupt();
 
-                throw new GridRuntimeException("Queue poll interrupted.", e);
+                throw new IgniteException("Queue poll interrupted.", e);
             }
 
             if (retVal != null)
@@ -329,7 +329,7 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
     /** {@inheritDoc} */
     @SuppressWarnings("unchecked")
-    @Override public void clear(int batchSize) throws GridRuntimeException {
+    @Override public void clear(int batchSize) throws IgniteException {
         A.ensure(batchSize >= 0, "Batch size cannot be negative: " + batchSize);
 
         try {
@@ -343,8 +343,8 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
             removeKeys(cache, id, queueName, collocated, t.get1(), t.get2(), batchSize);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -382,11 +382,11 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
      * @param startIdx Start item index.
      * @param endIdx End item index.
      * @param batchSize Batch size.
      * @throws GridException If failed.
      */
     @SuppressWarnings("unchecked")
     static void removeKeys(GridCacheProjection cache, IgniteUuid id, String name, boolean collocated, long startIdx,
-        long endIdx, int batchSize) throws GridException {
+        long endIdx, int batchSize) throws IgniteCheckedException {
         Collection<GridCacheQueueItemKey> keys = new ArrayList<>(batchSize > 0 ? batchSize : 10);
 
         for (long idx = startIdx; idx < endIdx; idx++) {
@@ -476,11 +476,11 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
     }
 
     /**
      * Throws {@link GridRuntimeException} in case if grid is stopping.
      */
     private void checkStopping() {
         if (cctx.kernalContext().isStopping())
-            throw new GridRuntimeException("Grid is stopping");
+            throw new IgniteException("Grid is stopping");
     }
 
     /**
@@ -494,9 +494,9 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
      * Removes item with given index from queue.
      *
      * @param rmvIdx Index of item to be removed.
      * @throws GridException If failed.
      */
-    protected abstract void removeItem(long rmvIdx) throws GridException;
+    protected abstract void removeItem(long rmvIdx) throws IgniteCheckedException;
 
 
     /**
@@ -551,10 +551,10 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
         /**
          * @param hdr Queue header.
          * @throws GridException If failed.
          */
         @SuppressWarnings("unchecked")
-        private QueueIterator(GridCacheQueueHeader hdr) throws GridException {
+        private QueueIterator(GridCacheQueueHeader hdr) throws IgniteCheckedException {
             idx = hdr.head();
             endIdx = hdr.tail();
             rmvIdxs = hdr.removedIndexes();
@@ -591,8 +591,8 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
                 return cur;
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
         }
 
@@ -606,8 +606,8 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
                 cur = null;
             }
-            catch (GridException e) {
-                throw new GridRuntimeException(e);
+            catch (IgniteCheckedException e) {
+                throw new IgniteException(e);
             }
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheQueueProxy.java
----------------------------------------------------------------------
@@ -382,11 +382,11 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
      * @param endIdx End item index.
      * @param batchSize Batch size.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings("unchecked")
@@ -476,11 +476,11 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
 
     /**
-     * Throws {@link GridRuntimeException} in case if grid is stopping.
+     * Throws {@link IgniteException} in case if grid is stopping.
      */
     private void checkStopping() {
@@ -494,9 +494,9 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
      *
      * @param rmvIdx Index of item to be removed.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
@@ -551,10 +551,10 @@ public abstract class GridCacheQueueAdapter<T> extends AbstractCollection<T> imp
         /**
          * @param hdr Queue header.
-         * @throws GridException If failed.
+         * @throws IgniteCheckedException If failed.
          */
         @SuppressWarnings("unchecked")
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetImpl.java
index 57a3085..9e6964c 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetImpl.java
@@ -132,8 +132,8 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
 
             return sum;
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -291,8 +291,8 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
                 return rmv;
             }
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -318,8 +318,8 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
                     retryRemoveAll(rmvKeys);
             }
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -357,8 +357,8 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
 
             return it;
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
     /**
@@ -369,8 +369,8 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
         try {
             return (R)ctx.dataStructures().retry(call);
         }
-        catch (GridException e) {
-            throw new GridRuntimeException(e);
+        catch (IgniteCheckedException e) {
+            throw new IgniteException(e);
         }
     }
 
@@ -403,10 +403,10 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
     /**
      * @param topVer Topology version.
      * @return Nodes where set data request should be sent.
      * @throws GridException If all cache nodes left grid.
      */
     @SuppressWarnings("unchecked")
-    private Collection<ClusterNode> dataNodes(long topVer) throws GridException {
+    private Collection<ClusterNode> dataNodes(long topVer) throws IgniteCheckedException {
         if (ctx.isLocal() || ctx.isReplicated())
             return Collections.singleton(ctx.localNode());
 
@@ -422,7 +422,7 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
             nodes = CU.affinityNodes(ctx, topVer);
 
         if (nodes.isEmpty())
-            throw new GridException("Failed to get set data, all cache nodes left grid.");
+            throw new IgniteCheckedException("Failed to get set data, all cache nodes left grid.");
 
         return nodes;
     }
@@ -441,7 +441,7 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
                 try {
                     fut.cancel();
                 }
-                catch (GridException e) {
+                catch (IgniteCheckedException e) {
                     log.error("Failed to close iterator.", e);
                 }
             }
@@ -471,7 +471,7 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
                 if (fut != null)
                     fut.cancel();
             }
-            catch (GridException e) {
+            catch (IgniteCheckedException e) {
                 log.error("Failed to close iterator.", e);
             }
         }
@@ -545,7 +545,7 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
         }
 
         /** {@inheritDoc} */
-        @Override protected T onNext() throws GridException {
+        @Override protected T onNext() throws IgniteCheckedException {
             init();
 
             if (next == null) {
@@ -567,7 +567,7 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
         }
 
         /** {@inheritDoc} */
-        @Override protected boolean onHasNext() throws GridException {
+        @Override protected boolean onHasNext() throws IgniteCheckedException {
             init();
 
             boolean hasNext = next != null;
@@ -579,14 +579,14 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
         }
 
         /** {@inheritDoc} */
-        @Override protected void onClose() throws GridException {
+        @Override protected void onClose() throws IgniteCheckedException {
             fut.cancel();
 
             clearWeakReference();
         }
 
         /** {@inheritDoc} */
-        @Override protected void onRemove() throws GridException {
+        @Override protected void onRemove() throws IgniteCheckedException {
             if (cur == null)
                 throw new NoSuchElementException();
 
@@ -594,9 +594,9 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
         }
 
         /**
          * @throws GridException If failed.
          */
-        private void init() throws GridException {
+        private void init() throws IgniteCheckedException {
             if (!init) {
                 Map.Entry e = (Map.Entry)fut.next();
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/datastructures/GridCacheSetProxy.java
----------------------------------------------------------------------
@@ -403,10 +403,10 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
      * @param topVer Topology version.
      * @return Nodes where set data request should be sent.
-     * @throws GridException If all cache nodes left grid.
+     * @throws IgniteCheckedException If all cache nodes left grid.
      */
     @SuppressWarnings("unchecked")
@@ -594,9 +594,9 @@ public class GridCacheSetImpl<T> extends AbstractCollection<T> implements GridCa
 
         /**
-         * @throws GridException If failed.
+         * @throws IgniteCheckedException If failed.
          */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockRequest.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockRequest.java
index 5130b65..519c3b7 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockRequest.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockRequest.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.nio.*;
@@ -266,7 +266,7 @@ public class GridDistributedLockRequest<K, V> extends GridDistributedBaseMessage
      * @param cands Candidates.
      * @param drVer DR version.
      * @param ctx Context.
      * @throws GridException If failed.
      */
     public void addKeyBytes(
         K key,
@@ -276,7 +276,7 @@ public class GridDistributedLockRequest<K, V> extends GridDistributedBaseMessage
         @Nullable Collection<GridCacheMvccCandidate<K>> cands,
         @Nullable GridCacheVersion drVer,
         GridCacheContext<K, V> ctx
-    ) throws GridException {
+    ) throws IgniteCheckedException {
         if (ctx.deploymentEnabled())
             prepareObject(key, ctx.shared());
 
@@ -381,7 +381,7 @@ public class GridDistributedLockRequest<K, V> extends GridDistributedBaseMessage
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (grpLockKey != null && grpLockKeyBytes == null) {
@@ -399,7 +399,7 @@ public class GridDistributedLockRequest<K, V> extends GridDistributedBaseMessage
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (keys == null)

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockResponse.java
----------------------------------------------------------------------
@@ -266,7 +266,7 @@ public class GridDistributedLockRequest<K, V> extends GridDistributedBaseMessage
      * @param drVer DR version.
      * @param ctx Context.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     public void addKeyBytes(
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockResponse.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockResponse.java
index 96c19ea..8edfc7c 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockResponse.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedLockResponse.java
@@ -9,14 +9,14 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
+import org.gridgain.grid.util.tostring.*;
 import org.gridgain.grid.util.typedef.*;
 import org.gridgain.grid.util.typedef.internal.*;
-import org.gridgain.grid.util.tostring.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -180,9 +180,9 @@ public class GridDistributedLockResponse<K, V> extends GridDistributedBaseMessag
      * @param val Value.
      * @param valBytes Value bytes (possibly {@code null}).
      * @param ctx Context.
      * @throws GridException If failed.
      */
-    public void addValueBytes(V val, @Nullable byte[] valBytes, GridCacheContext<K, V> ctx) throws GridException {
+    public void addValueBytes(V val, @Nullable byte[] valBytes, GridCacheContext<K, V> ctx) throws IgniteCheckedException {
         if (ctx.deploymentEnabled())
             prepareObject(val, ctx.shared());
 
@@ -233,7 +233,7 @@ public class GridDistributedLockResponse<K, V> extends GridDistributedBaseMessag
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (F.isEmpty(valBytes) && !F.isEmpty(vals))
@@ -244,7 +244,7 @@ public class GridDistributedLockResponse<K, V> extends GridDistributedBaseMessag
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (F.isEmpty(vals) && !F.isEmpty(valBytes))

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxFinishRequest.java
----------------------------------------------------------------------
@@ -180,9 +180,9 @@ public class GridDistributedLockResponse<K, V> extends GridDistributedBaseMessag
      * @param valBytes Value bytes (possibly {@code null}).
      * @param ctx Context.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
index f74c71f..3cd3e2d 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedTxRemoteAdapter.java
@@ -9,16 +9,16 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
-import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.near.*;
-import org.gridgain.grid.util.typedef.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.future.*;
 import org.gridgain.grid.util.lang.*;
 import org.gridgain.grid.util.tostring.*;
+import org.gridgain.grid.util.typedef.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -273,7 +273,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
                 return true;
             }
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             U.error(log, "Failed to commit remote transaction: " + this, e);
         }
 
@@ -413,9 +413,9 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
     /**
      * Prepare phase.
      *
      * @throws GridException If prepare failed.
      */
-    @Override public void prepare() throws GridException {
+    @Override public void prepare() throws IgniteCheckedException {
         // If another thread is doing prepare or rollback.
         if (!state(PREPARING)) {
             // In optimistic mode prepare may be called multiple times.
@@ -433,7 +433,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
             if (pessimistic() || isSystemInvalidate())
                 state(PREPARED);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             setRollbackOnly();
 
             throw e;
@@ -441,10 +441,10 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
     }
 
     /**
      * @throws GridException If commit failed.
      */
     @SuppressWarnings({"CatchGenericClass"})
-    private void commitIfLocked() throws GridException {
+    private void commitIfLocked() throws IgniteCheckedException {
         if (state() == COMMITTING) {
             for (GridCacheTxEntry<K, V> txEntry : writeMap.values()) {
                 assert txEntry != null : "Missing transaction entry for tx: " + this;
@@ -479,7 +479,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
 
             // Only one thread gets to commit.
             if (commitAllowed.compareAndSet(false, true)) {
-                GridException err = null;
+                IgniteCheckedException err = null;
 
                 if (!F.isEmpty(writeMap)) {
                     // Register this transaction as completed prior to write-phase to
@@ -669,8 +669,8 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
 
                             // In case of error, we still make the best effort to commit,
                             // as there is no way to rollback at this point.
-                            err = ex instanceof GridException ? (GridException)ex :
-                                new GridException("Commit produced a runtime exception: " + this, ex);
+                            err = ex instanceof IgniteCheckedException ? (IgniteCheckedException)ex :
+                                new IgniteCheckedException("Commit produced a runtime exception: " + this, ex);
                         }
                     }
                 }
@@ -689,7 +689,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
     }
 
     /** {@inheritDoc} */
-    @Override public void commit() throws GridException {
+    @Override public void commit() throws IgniteCheckedException {
         if (optimistic())
             state(PREPARED);
 
@@ -706,7 +706,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
             setRollbackOnly();
 
             if (!isSystemInvalidate())
-                throw new GridException("Invalid transaction state for commit [state=" + state + ", tx=" + this + ']');
+                throw new IgniteCheckedException("Invalid transaction state for commit [state=" + state + ", tx=" + this + ']');
 
             rollback();
         }
@@ -717,9 +717,9 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
     /**
      * Forces commit for this tx.
      *
      * @throws GridException If commit failed.
      */
-    public void forceCommit() throws GridException {
+    public void forceCommit() throws IgniteCheckedException {
         commitIfLocked();
     }
 
@@ -730,7 +730,7 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
 
             return new GridFinishedFutureEx<GridCacheTx>(this);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             return new GridFinishedFutureEx<>(e);
         }
     }

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedUnlockRequest.java
----------------------------------------------------------------------
@@ -413,9 +413,9 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
      * Prepare phase.
      *
-     * @throws GridException If prepare failed.
+     * @throws IgniteCheckedException If prepare failed.
      */
@@ -441,10 +441,10 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
 
     /**
-     * @throws GridException If commit failed.
+     * @throws IgniteCheckedException If commit failed.
      */
     @SuppressWarnings({"CatchGenericClass"})
@@ -717,9 +717,9 @@ public class GridDistributedTxRemoteAdapter<K, V> extends GridCacheTxAdapter<K,
      * Forces commit for this tx.
      *
-     * @throws GridException If commit failed.
+     * @throws IgniteCheckedException If commit failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedUnlockRequest.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedUnlockRequest.java
index 3e49e5b..93e3ccf 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedUnlockRequest.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridDistributedUnlockRequest.java
@@ -9,7 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
-import org.gridgain.grid.*;
+import org.apache.ignite.*;
 import org.gridgain.grid.kernal.*;
 import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.util.direct.*;
@@ -70,9 +70,9 @@ public class GridDistributedUnlockRequest<K, V> extends GridDistributedBaseMessa
      * @param key Key.
      * @param bytes Key bytes.
      * @param ctx Context.
      * @throws GridException If failed.
      */
-    public void addKey(K key, byte[] bytes, GridCacheContext<K, V> ctx) throws GridException {
+    public void addKey(K key, byte[] bytes, GridCacheContext<K, V> ctx) throws IgniteCheckedException {
         boolean depEnabled = ctx.deploymentEnabled();
 
         if (depEnabled)
@@ -91,7 +91,7 @@ public class GridDistributedUnlockRequest<K, V> extends GridDistributedBaseMessa
 
     /** {@inheritDoc}
      * @param ctx*/
-    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws GridException {
+    @Override public void prepareMarshal(GridCacheSharedContext<K, V> ctx) throws IgniteCheckedException {
         super.prepareMarshal(ctx);
 
         if (F.isEmpty(keyBytes) && !F.isEmpty(keys))
@@ -99,7 +99,7 @@ public class GridDistributedUnlockRequest<K, V> extends GridDistributedBaseMessa
     }
 
     /** {@inheritDoc} */
-    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws GridException {
+    @Override public void finishUnmarshal(GridCacheSharedContext<K, V> ctx, ClassLoader ldr) throws IgniteCheckedException {
         super.finishUnmarshal(ctx, ldr);
 
         if (keys == null && !F.isEmpty(keyBytes))

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridPartitionedCacheEntryImpl.java
----------------------------------------------------------------------
@@ -70,9 +70,9 @@ public class GridDistributedUnlockRequest<K, V> extends GridDistributedBaseMessa
      * @param bytes Key bytes.
      * @param ctx Context.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
diff --git a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridPartitionedCacheEntryImpl.java b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridPartitionedCacheEntryImpl.java
index b3c98f8..7810847 100644
--- a/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridPartitionedCacheEntryImpl.java
+++ b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/GridPartitionedCacheEntryImpl.java
@@ -9,6 +9,7 @@
 
 package org.gridgain.grid.kernal.processors.cache.distributed;
 
+import org.apache.ignite.*;
 import org.apache.ignite.lang.*;
 import org.gridgain.grid.*;
 import org.gridgain.grid.cache.*;
@@ -16,10 +17,10 @@ import org.gridgain.grid.kernal.processors.cache.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.dht.colocated.*;
 import org.gridgain.grid.kernal.processors.cache.distributed.near.*;
-import org.gridgain.grid.util.typedef.*;
-import org.gridgain.grid.util.typedef.internal.*;
 import org.gridgain.grid.util.*;
 import org.gridgain.grid.util.lang.*;
+import org.gridgain.grid.util.typedef.*;
+import org.gridgain.grid.util.typedef.internal.*;
 import org.jetbrains.annotations.*;
 
 import java.io.*;
@@ -70,7 +71,7 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
     }
 
     /** {@inheritDoc} */
-    @Override public V peek(@Nullable Collection<GridCachePeekMode> modes) throws GridException {
+    @Override public V peek(@Nullable Collection<GridCachePeekMode> modes) throws IgniteCheckedException {
         if (modes.contains(NEAR_ONLY) && ctx.isNear())
             return peekNear0(modes, CU.<K, V>empty());
 
@@ -93,9 +94,9 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
         try {
             return peekDht0(SMART, filter);
         }
-        catch (GridException e) {
+        catch (IgniteCheckedException e) {
             // Should never happen.
-            throw new GridRuntimeException("Unable to perform entry peek() operation.", e);
+            throw new IgniteException("Unable to perform entry peek() operation.", e);
         }
     }
 
@@ -103,10 +104,10 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param modes Peek modes.
      * @param filter Optional entry filter.
      * @return Peeked value.
      * @throws GridException If failed.
      */
     @Nullable private V peekNear0(@Nullable Collection<GridCachePeekMode> modes,
-        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws GridException {
+        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws IgniteCheckedException {
         if (F.isEmpty(modes))
             return peekNear0(SMART, filter);
 
@@ -126,11 +127,11 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param mode Peek mode.
      * @param filter Optional entry filter.
      * @return Peeked value.
      * @throws GridException If failed.
      */
     @SuppressWarnings({"unchecked"})
     @Nullable private V peekNear0(@Nullable GridCachePeekMode mode,
-        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws GridException {
+        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws IgniteCheckedException {
         if (mode == null)
             mode = SMART;
 
@@ -160,10 +161,10 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param modes Peek modes.
      * @param filter Optional entry filter.
      * @return Peeked value.
      * @throws GridException If failed.
      */
     @Nullable private V peekDht0(@Nullable Collection<GridCachePeekMode> modes,
-        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws GridException {
+        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws IgniteCheckedException {
         if (F.isEmpty(modes))
             return peekDht0(SMART, filter);
 
@@ -183,11 +184,11 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param mode Peek mode.
      * @param filter Optional entry filter.
      * @return Peeked value.
      * @throws GridException If failed.
      */
     @SuppressWarnings({"unchecked"})
     @Nullable private V peekDht0(@Nullable GridCachePeekMode mode,
-        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws GridException {
+        @Nullable IgnitePredicate<GridCacheEntry<K, V>>[] filter) throws IgniteCheckedException {
         if (mode == null)
             mode = SMART;
 

http://git-wip-us.apache.org/repos/asf/incubator-ignite/blob/06931b4b/modules/core/src/main/java/org/gridgain/grid/kernal/processors/cache/distributed/dht/GridClientPartitionTopology.java
----------------------------------------------------------------------
@@ -103,10 +104,10 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param filter Optional entry filter.
      * @return Peeked value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @Nullable private V peekNear0(@Nullable Collection<GridCachePeekMode> modes,
@@ -126,11 +127,11 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param filter Optional entry filter.
      * @return Peeked value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings({"unchecked"})
@@ -160,10 +161,10 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param filter Optional entry filter.
      * @return Peeked value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @Nullable private V peekDht0(@Nullable Collection<GridCachePeekMode> modes,
@@ -183,11 +184,11 @@ public class GridPartitionedCacheEntryImpl<K, V> extends GridCacheEntryImpl<K, V
      * @param filter Optional entry filter.
      * @return Peeked value.
-     * @throws GridException If failed.
+     * @throws IgniteCheckedException If failed.
      */
     @SuppressWarnings({"unchecked"})